@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Fix the configuration of an application
 
 package App::Cme::Command::fix ;
-$App::Cme::Command::fix::VERSION = '1.006';
+$App::Cme::Command::fix::VERSION = '1.010';
 use strict;
 use warnings;
 use 5.10.1;
@@ -31,7 +31,7 @@ sub opt_spec {
     return ( 
         [ "from=s@"  => "fix only a subset of a configuration tree" ],
         [ "filter=s" => "pattern to select the element name to be fixed"],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -78,7 +78,7 @@ App::Cme::Command::fix - Fix the configuration of an application
 
 =head1 VERSION
 
-version 1.006
+version 1.010
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dominique Dumont.
+This software is Copyright (c) 2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
