@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with fuse
 
 package App::Cme::Command::fusefs ;
-$App::Cme::Command::fusefs::VERSION = '1.006';
+$App::Cme::Command::fusefs::VERSION = '1.010';
 use strict;
 use warnings;
 use 5.10.1;
@@ -45,7 +45,7 @@ sub opt_spec {
         ],
         [ "dfuse!" => "debug fuse problems" ],
         [ "dir-char=s" => "string to replace '/' in configuration parameter names"],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -107,7 +107,7 @@ App::Cme::Command::fusefs - Edit the configuration of an application with fuse
 
 =head1 VERSION
 
-version 1.006
+version 1.010
 
 =head1 SYNOPSIS
 
@@ -155,7 +155,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dominique Dumont.
+This software is Copyright (c) 2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
