@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Migrate the configuration of an application
 
 package App::Cme::Command::migrate ;
-$App::Cme::Command::migrate::VERSION = '1.006';
+$App::Cme::Command::migrate::VERSION = '1.010';
 use strict;
 use warnings;
 use 5.10.1;
@@ -29,7 +29,7 @@ sub validate_args {
 sub opt_spec {
     my ( $class, $app ) = @_;
     return (
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -68,7 +68,7 @@ App::Cme::Command::migrate - Migrate the configuration of an application
 
 =head1 VERSION
 
-version 1.006
+version 1.010
 
 =head1 SYNOPSIS
 
@@ -97,7 +97,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dominique Dumont.
+This software is Copyright (c) 2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
