@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application with a shell
 
 package App::Cme::Command::shell ;
-$App::Cme::Command::shell::VERSION = '1.006';
+$App::Cme::Command::shell::VERSION = '1.010';
 use strict;
 use warnings;
 use 5.10.1;
@@ -28,7 +28,7 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "open-item=s" => "open a specific item of the configuration" ],
-        $class->global_options,
+        $class->cme_global_options,
     );
 }
 
@@ -65,7 +65,7 @@ App::Cme::Command::shell - Edit the configuration of an application with a shell
 
 =head1 VERSION
 
-version 1.006
+version 1.010
 
 =head1 SYNOPSIS
 
@@ -101,7 +101,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dominique Dumont.
+This software is Copyright (c) 2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
